from typing import Dict, List, Any
from datetime import datetime
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


class FrenchJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        url = 'https://jpa.narcotiquesanonymes.org/'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')

        result = {
            'date': '',
            'quote': '',
            'source': '',
            'thought': '',
            'content': [],
            'title': '',
            'page': '',
            'copyright': f'Copyright (c) {datetime.now().year}, NA World Service, Inc. All Rights Reserved',
        }

        # Extract the title
        title_element = soup.find('div', class_='cartouche').find('h1')
        if title_element:
            result['title'] = title_element.get_text().strip()

        # Extract the date
        date_element = soup.find('p', class_='info-publi')
        if date_element:
            result['date'] = date_element.get_text().strip()

        # Extract the quote and source
        quote_div = soup.find('div', class_='chapo')
        if quote_div:
            quote_p_tags = quote_div.find_all('p')
            if len(quote_p_tags) >= 2:
                result['quote'] = quote_p_tags[0].get_text().strip()
                result['source'] = quote_p_tags[1].get_text().strip()

        # Extract the thought
        thought_element = soup.find('h3', class_='h3 spip')
        if thought_element:
            result['thought'] = thought_element.get_text().strip()

        # Extract the content
        text_div = soup.find('div', class_='texte')
        if text_div:
            p_tags = text_div.find_all('p')
            for p_tag in p_tags:
                result['content'].append(p_tag.get_text().strip())

        return JftEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



from dataclasses import dataclass
from typing import Dict, List, Any
from fetch_meditation.spad_language import SpadLanguage
from fetch_meditation.english_spad import EnglishSpad


@dataclass
class Spad:
    settings: Any

    def fetch(self) -> None:
        pass

    @property
    def language(self) -> SpadLanguage:
        return self.settings.language

    @staticmethod
    def get_instance(settings: Any) -> EnglishSpad:
        return {
            SpadLanguage.English: EnglishSpad,
        }[settings.language](settings)



from typing import Dict, List, Any
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


class EnglishJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        url = 'https://www.jftna.org/jft/'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')
        td_elements = soup.find_all('td')
        jft_keys = ['date', 'title', 'page', 'quote',
                    'source', 'content', 'thought', 'copyright']
        result: Dict[str, Any] = {}

        for i, td in enumerate(td_elements):
            if jft_keys[i] == 'content':
                inner_html = ''.join(str(child) for child in td.children)
                result['content'] = [line.strip()
                                     for line in inner_html.split('<br/>') if line.strip()]
            else:
                result[jft_keys[i]] = td.text.strip()

        result["copyright"] = ' '.join(result["copyright"].split())

        return JftEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



import pytest
from fetch_meditation.spad_language import SpadLanguage
from fetch_meditation.spad_settings import SpadSettings
from fetch_meditation.english_spad import EnglishSpad
from fetch_meditation.spad import Spad


@pytest.fixture(params=[
    (EnglishSpad, SpadLanguage.English),
])
def language_cls(request):
    return request.param


def test_jft_language_property(language_cls):
    spad_cls, language = language_cls
    spad_settings = SpadSettings(language)
    spad_instance = Spad(spad_settings)

    assert spad_instance.language == language


def test_get_instance(language_cls):
    spad_cls, language = language_cls
    spad_settings = SpadSettings(language)
    spad_instance = Spad.get_instance(spad_settings)

    assert isinstance(spad_instance, spad_cls)



from typing import Dict, List, Any
import json
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


class ItalianJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        url = 'https://na-italia.org/get-jft'
        response = HttpUtility.http_get(url)
        data = json.loads(response)[0]
        html_content = data['content']
        soup = BeautifulSoup(html_content, 'html.parser')

        paragraphs = soup.find_all('p')

        initial_result = {
            'quote': '',
            'source': '',
            'thought': '',
            'copyright': '',
            'page': '',
        }

        # Split the title and date parts
        title_parts = data['title'].split(',')
        initial_result['title'] = title_parts[0].strip()
        initial_result['date'] = title_parts[-1].strip()

        # Populate the result dictionary with paragraph content
        for index, paragraph in enumerate(paragraphs):
            key = 'quote' if index == 0 else str(index + 1)
            initial_result[key] = paragraph.get_text()

        result = {
            'content': [],
            'thought': '',
            'source': '',
        }

        lastNumericKey = None
        firstNumericKeyWithSource = None

        # Iterate through the initial_result dictionary and categorize content
        for key, value in initial_result.items():
            if value.startswith('--'):
                firstNumericKeyWithSource = key
                result['source'] = value[2:]
            if key.isdigit():
                lastNumericKey = key
                result['content'].append(value)
                result['thought'] = value
            else:
                result[key] = value

        # Remove unnecessary content entries
        result['content'] = result['content'][:-1]

        quote_parts = result['quote'].split('--')
        result['quote'] = quote_parts[0].strip()
        result['source'] = quote_parts[1].strip() if len(quote_parts) > 1 else result['source']

        return JftEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



from dataclasses import dataclass
from typing import Any, Union
from fetch_meditation.jft_language import JftLanguage
from fetch_meditation.english_jft import EnglishJft
from fetch_meditation.french_jft import FrenchJft
from fetch_meditation.german_jft import GermanJft
from fetch_meditation.italian_jft import ItalianJft
from fetch_meditation.japanese_jft import JapaneseJft
from fetch_meditation.portuguese_jft import PortugueseJft
from fetch_meditation.russian_jft import RussianJft
from fetch_meditation.spanish_jft import SpanishJft
from fetch_meditation.swedish_jft import SwedishJft


@dataclass
class Jft:
    settings: Any

    @property
    def language(self) -> JftLanguage:
        return self.settings.language

    @staticmethod
    def get_instance(settings: Any) -> Union[EnglishJft, FrenchJft, GermanJft, ItalianJft, JapaneseJft, PortugueseJft, RussianJft, SpanishJft, SwedishJft]:
        return {
            JftLanguage.English: EnglishJft,
            JftLanguage.French: FrenchJft,
            JftLanguage.German: GermanJft,
            JftLanguage.Italian: ItalianJft,
            JftLanguage.Japanese: JapaneseJft,
            JftLanguage.Portuguese: PortugueseJft,
            JftLanguage.Russian: RussianJft,
            JftLanguage.Spanish: SpanishJft,
            JftLanguage.Swedish: SwedishJft,
        }[settings.language](settings)



from typing import Dict, List, Any
import re
import pytz
from datetime import datetime
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


def remove_newlines_from_dict(input_dict):
    for key, value in input_dict.items():
        if isinstance(value, str):
            input_dict[key] = value.replace('\n', '')
        elif isinstance(value, dict):
            remove_newlines_from_dict(value)


class SpanishJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        timezone = pytz.timezone('America/Mexico_City')
        date = datetime.now(timezone)
        url = 'https://forozonalatino.org/wp-content/uploads/meditaciones/' + date.strftime('%m/%d') + '.html'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')

        # Get content
        paragraphs = []
        for i in range(1, 4):
            comment = soup.find(string=f'PARRAFO {i}')
            if comment:
                paragraph = comment.find_next('p').get_text(strip=True)
                if not paragraph.startswith("Sólo por Hoy"):
                    paragraphs.append(paragraph.replace("\n", ""))

        # Get Thought
        start_comment = soup.find(string='SOLO X HOY insertar AQUI sin el Solo por Hoy')
        end_comment = soup.find(string='FIN SOLO X HOY')

        extracted_thought = ''
        if start_comment and end_comment:
            start_node = start_comment.find_next_sibling()
            while start_node and start_node != end_comment:
                extracted_thought += str(start_node)
                start_node = start_node.find_next_sibling()

        result = {}
        for element in soup.find_all('p'):
            class_name = element.get('class', [])
            if class_name == ['fecha-sxh']:
                result['date'] = element.get_text()
            elif class_name == ['titulo-sxh']:
                result['title'] = element.get_text()
            elif class_name == ['descripcion-sxh']:
                result['quote'] = element.get_text(strip=True)
            elif class_name == ['numero-pagina-sxh']:
                result['source'] = element.get_text()

        thought_div = soup.find('div', attrs={'id': 'soloxhoycontainer'})
        thought = thought_div.get_text(strip=True).replace("\n", "")
        result['thought'] = re.sub(r'(Sólo por Hoy:)', r'<b>\1 </b> ', thought)

        result['content'] = paragraphs
        result['page'] = ''
        result[
            'copyright'] = 'Servicio del Foro Zonal Latinoamericano, Copyright 2017 NA World Services, Inc. Todos los Derechos Reservados.'
        remove_newlines_from_dict(result)
        return JftEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



from datetime import datetime
from typing import Dict, List, Any
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


class JapaneseJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        url = 'https://najapan.org/just_for_today/'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')
        result = {
            'date': '',
            'quote': '',
            'source': '',
            'thought': '',
            'content': [],
            'title': '',
            'page': '',
            'copyright': f'Copyright (c) {datetime.now().year}, NA World Service, Inc. All Rights Reserved',
        }

        # Extract the date and title
        h2_element = soup.find('h2')
        if h2_element:
            date_parts = h2_element.text.split("　")
            result['date'] = date_parts[0].strip()
            result['title'] = date_parts[-1].strip()

        # Extract quote
        p0_element = soup.find('p')
        if p0_element:
            result['quote'] = p0_element.next_element.get_text(strip=True).replace("\n", "")

        # Extract the source and page
        p1_element = soup.find_all('p')[1]
        if p1_element:
            result['source'] = p1_element.text.strip()

        p_tags = soup.find_all('p')
        p_tag_count = len(p_tags)

        # Extract the thought
        if p_tag_count >= 2:
            thought_p_tag = p_tags[-2]
            result['thought'] = thought_p_tag.text.strip()

        # Extract the copyright
        center_tags = soup.find_all('center')
        if center_tags:
            result['copyright'] = center_tags[0].text.strip()

        # Extract the content
        right_aligned_p = soup.find('p', style="text-align:right")
        paragraph_content = right_aligned_p.next_element.next_element.next_element
        filtered_content = []
        while True:
            if paragraph_content.name == 'b':
                break
            if paragraph_content.name is None:
                filtered_content.append(paragraph_content.strip())
            paragraph_content = paragraph_content.next_element
        result['content'] = [i for i in filtered_content if i]

        return JftEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



import pytest
from fetch_meditation.jft_settings import JftSettings
from fetch_meditation.jft_language import JftLanguage


def test_constructor():
    settings = JftSettings(JftLanguage.English)
    assert settings.language == JftLanguage.English



import pytest
from fetch_meditation.spad_settings import SpadSettings
from fetch_meditation.spad_language import SpadLanguage


def test_constructor():
    settings = SpadSettings(SpadLanguage.English)
    assert settings.language == SpadLanguage.English




__version__ = '0.1.7'

from fetch_meditation.jft_language import JftLanguage
from fetch_meditation.jft_settings import JftSettings
from fetch_meditation.jft import Jft
from fetch_meditation.spad_language import SpadLanguage
from fetch_meditation.spad_settings import SpadSettings
from fetch_meditation.spad import Spad



from typing import Dict, List, Any
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


class PortugueseJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        url = 'https://www.na.org.br/meditacao/'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')

        # Extract paragraphs
        paragraph_div = soup.find('div', id='sep-i')
        paragraph_content = paragraph_div.next_element
        filtered_content = ''
        while True:
            if paragraph_content.name == 'div':
                break
            filtered_content += str(paragraph_content)
            paragraph_content = paragraph_content.next_element
        paragraphs = [t.strip() for t in filtered_content.split("<br/>") if t.strip()]

        # Extract other elements
        result = {}
        for element in soup.find_all('p'):
            class_attr = element.get('class')[0] if element.get('class') else None
            text = element.get_text(strip=True)
            if class_attr == 'dat':
                result['date'] = text
            elif class_attr == 'cit':
                result['source'] = text
            elif class_attr == 'ef':
                result['quote'] = text
            elif class_attr == 'sph':
                result['thought'] = ' '.join(text.split())
            elif class_attr == 'ct':
                result['copyright'] = ' '.join(text.replace("\n", "").split())

        # Extract the title
        title_element = soup.find('h1', class_='tit')
        result['title'] = title_element.get_text(strip=True) if title_element else ''

        # Create the final result dictionary
        result['page'] = ''
        result['content'] = paragraphs

        return JftEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



from typing import Dict, List, Any
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


class GermanJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        url = 'https://narcotics-anonymous.de/artikel/nur-fuer-heute/'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')
        container = soup.find('div', {'id': 'jft-container'})
        result: Dict[str, Any] = {}

        for node in container.children:
            if node.name is not None:
                id = node.get('id')
                if id == 'jft-content':
                    content_list = []
                    for contentNode in node.find_all('p'):
                        content_list.append(contentNode.get_text(
                            strip=True).replace('\n', ' '))
                    result[id] = content_list
                else:
                    result[id] = node.get_text(strip=True).replace('\n', '')
        result['page'] = ''
        result['copyright'] = ''
        result['jft-content'] = list(filter(None, result['jft-content']))

        return JftEntry(
            result['jft-date'],
            result['jft-title'],
            result['page'],
            result['jft-quote'],
            result['jft-quote-source'],
            result['jft-content'],
            result['jft-thought'],
            result['copyright']
        )



from typing import Dict, List, Any
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


class RussianJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        url = 'https://na-russia.org/eg'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')
        jftKeys = ['date', 'title', 'quote',
                   'source', 'content', 'thought', 'page']

        result = {
            'date': '',
            'quote': '',
            'source': '',
            'thought': '',
            'content': [],
            'title': '',
            'page': '',
            'copyright': ''
        }

        tables = soup.find_all('table')
        if len(tables) > 0:
            firstTable = tables[0]
            td_list = firstTable.find_all('td')
            for i, td in enumerate(td_list):
                if jftKeys[i] == 'content':
                    innerHTML = ''.join(str(child) for child in td.contents)
                    result['content'] = [line.strip()
                                         for line in innerHTML.split('<br/>') if line.strip()]
                else:
                    result[jftKeys[i]] = td.get_text().strip()

        return JftEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



import json
from typing import Any, Dict, List
from dataclasses import dataclass
from bs4 import BeautifulSoup


@dataclass
class SpadEntry:
    date: str
    title: str
    page: str
    quote: str
    source: str
    content: List[str]
    thought: str
    copyright: str

    def _to_dict(self) -> Dict[str, Any]:
        return {
            'date': self.date,
            'title': self.title,
            'page': self.page,
            'quote': self.quote,
            'source': self.source,
            'content': self.content,
            'thought': self.thought,
            'copyright': self.copyright
        }

    def to_json(self) -> str:
        return json.dumps(self._to_dict())

    def without_tags(self) -> Dict[str, Any]:
        def strip_tags(item: str) -> str:
            if isinstance(item, list):
                return [strip_tags(sub_item) for sub_item in item]
            else:
                soup = BeautifulSoup(item, 'html.parser')
                return soup.text

        return {key: strip_tags(value) for key, value in self._to_dict().items()}



from typing import Dict, List, Any
from bs4 import BeautifulSoup
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.spad_entry import SpadEntry


class EnglishSpad:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'SpadEntry':
        url = 'https://www.spadna.org/'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')
        td_elements = soup.find_all('td')
        spad_keys = ['date', 'title', 'page', 'quote', 'source',
                     'content', 'divider', 'thought', 'copyright']
        result: Dict[str, Any] = {}

        for i, td in enumerate(td_elements):
            if spad_keys[i] == 'content':
                inner_html = ''.join(str(child) for child in td.children)
                result['content'] = [line.strip()
                                     for line in inner_html.split('<br/>') if line.strip()]
            else:
                result[spad_keys[i]] = td.text.strip()

        result["copyright"] = ' '.join(result["copyright"].split())

        return SpadEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



import json
import pytest
from fetch_meditation.spad_entry import SpadEntry


@pytest.fixture
def sample_entry():
    return SpadEntry(
        '2023-10-26',
        'Sample Title',
        'Sample Page',
        'Sample Quote',
        'Sample Source',
        ['Content Line 1', 'Content Line 2'],
        'Sample Thought',
        'Sample Copyright'
    )


def test_spad_entry_properties(sample_entry):
    entry = sample_entry

    assert isinstance(entry.date, str)
    assert isinstance(entry.title, str)
    assert isinstance(entry.page, str)
    assert isinstance(entry.quote, str)
    assert isinstance(entry.source, str)
    assert isinstance(entry.content, list)
    assert isinstance(entry.thought, str)
    assert isinstance(entry.copyright, str)


def test_spad_entry_without_tags(sample_entry):
    entry = sample_entry
    entry.title = 'Sample <br>Title'

    result = entry.without_tags()
    assert result['title'] == 'Sample Title'


def test_spad_entry_to_json(sample_entry):
    entry = sample_entry
    response_data = entry.to_json()
    decoded_response = json.loads(response_data)

    assert decoded_response is not None
    assert 'date' in decoded_response
    assert 'title' in decoded_response
    assert 'page' in decoded_response
    assert 'quote' in decoded_response
    assert 'source' in decoded_response
    assert 'content' in decoded_response
    assert 'thought' in decoded_response
    assert 'copyright' in decoded_response



import pytest
from fetch_meditation.jft_language import JftLanguage
from fetch_meditation.jft_settings import JftSettings
from fetch_meditation.english_jft import EnglishJft
from fetch_meditation.french_jft import FrenchJft
from fetch_meditation.german_jft import GermanJft
from fetch_meditation.italian_jft import ItalianJft
from fetch_meditation.portuguese_jft import PortugueseJft
from fetch_meditation.japanese_jft import JapaneseJft
from fetch_meditation.russian_jft import RussianJft
from fetch_meditation.spanish_jft import SpanishJft
from fetch_meditation.swedish_jft import SwedishJft
from fetch_meditation.jft import Jft


@pytest.fixture(params=[
    (EnglishJft, JftLanguage.English),
    (FrenchJft, JftLanguage.French),
    (GermanJft, JftLanguage.German),
    (ItalianJft, JftLanguage.Italian),
    (PortugueseJft, JftLanguage.Portuguese),
    (JapaneseJft, JftLanguage.Japanese),
    (RussianJft, JftLanguage.Russian),
    (SpanishJft, JftLanguage.Spanish),
    (SwedishJft, JftLanguage.Swedish),
])
def language_cls(request):
    return request.param


def test_jft_language_property(language_cls):
    jft_cls, language = language_cls
    jft_settings = JftSettings(language)
    jft_instance = Jft(jft_settings)

    assert jft_instance.language == language


def test_get_instance(language_cls):
    jft_cls, language = language_cls
    jft_settings = JftSettings(language)
    jft_instance = Jft.get_instance(jft_settings)

    assert isinstance(jft_instance, jft_cls)



from typing import Dict, List, Any
from bs4 import BeautifulSoup
from datetime import datetime
from fetch_meditation.utilities.http_utility import HttpUtility
from fetch_meditation.jft_entry import JftEntry


class SwedishJft:
    def __init__(self, settings: Any) -> None:
        self.settings = settings

    def fetch(self) -> 'JftEntry':
        url = 'https://www.nasverige.org/dagens-text/'
        data = HttpUtility.http_get(url)
        soup = BeautifulSoup(data, 'html.parser')

        result = {
            'date': '',
            'quote': '',
            'source': '',
            'thought': '',
            'content': [],
            'title': '',
            'page': '',
            'copyright': f'Copyright (c) {datetime.now().year}, NA World Service, Inc. All Rights Reserved',
        }

        # Extract the date
        date_element = soup.find('div', class_='border-bottom mb-4').find('p', class_='h3')
        if date_element:
            result['date'] = date_element.text.strip()

        # Extract the title
        title_element = soup.find('div', class_='border-bottom mb-4').find('h2')
        if title_element:
            result['title'] = title_element.text.strip()

        # Extract the quote and source
        quote_element = soup.find('p', class_='bg-lightBlue p-4 preamble')
        if quote_element:
            result['quote'] = quote_element.text.strip()
            result['quote'] = ' '.join(result['quote'].split())
            quote_parts = result['quote'].split('/')
            result['quote'] = quote_parts[0].strip()
            result['source'] = quote_parts[-1].strip()

        # Extract the thought
        thought_element = soup.find('div', class_='col-12 col-md-8 col-lg-6 pt-5').find_all('p')[1]
        if thought_element:
            result['thought'] = thought_element.text.strip()

        # Extract the content
        content_element = soup.find('div', class_='col-12 col-md-8 col-lg-6 pt-5').find_all('p')[0]
        if content_element:
            items = [item.strip() for item in content_element.text.strip().split('\n')]
            result['content'] = list(filter(None, items))

        return JftEntry(
            result['date'],
            result['title'],
            result['page'],
            result['quote'],
            result['source'],
            result['content'],
            result['thought'],
            result['copyright']
        )



import urllib3
from urllib3.exceptions import HTTPError


class HttpUtility:
    def __init__(self):
        pass

    @staticmethod
    def http_get(url):
        http = urllib3.PoolManager()
        headers = {
            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:105.0) Gecko/20100101 Firefox/105.0'
        }

        try:
            response = http.request('GET', url, headers=headers)
            if response.status in [200, 302, 304]:
                return response.data.decode('utf-8')
            else:
                raise Exception(
                    'Received non-acceptable status code: ' + str(response.status))
        except HTTPError as e:
            raise Exception('HTTP error occurred: ' + str(e))
